@@ -3,6 +3,6 @@ use strict;
 use warnings;
 use Log::Accounting::SVK;
 
-my $repo = shift || die "Have to give a repository path\n";
+my $repo = shift || '.';
 
 Log::Accounting::SVK->new(repository => $repo)->process->report;
